==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiPage/InsertCommentVisitor.pm <==
#
# WiKicker
#
#  InsertCommitVisitor.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: InsertCommentVisitor.pm,v 1.4 2003/11/01 11:59:23 naney Exp $
#
#

package WiKicker::WikiPage::InsertCommentVisitor;

use strict;

use WiKicker::PageName;
use WiKicker::WikiPage::TraverseVisitor;
use WiKicker::WikiPage::TextNode;
use WiKicker::Time;
use vars qw(@ISA);
@ISA = qw(WiKicker::WikiPage::TraverseVisitor);

sub new {
  my $class = shift;

  my $self = bless { current_number => -1 }, $class;
}

sub comment_name {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{comment_name} = $value;
  }
  return $self->{comment_name};
}

sub comment_number {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{comment_number} = $value;
  }
  return $self->{comment_number};
}

sub comment_message {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{comment_message} = $value;
  }
  return $self->{comment_message};
}

sub comment_gmtime {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{comment_gmtime} = $value;
  }
  return $self->{comment_gmtime};
}

sub visit_WriNode {
  my ($self, $wri_node) = @_;

  #warn $wri_node->wri->scheme;
  
  if ($self->is_comment($wri_node->wri)) {
    $self->{current_number}++;
    if ($self->{current_number} == $self->comment_number) {
      $self->insert_comment($wri_node);
    }
  }
}

sub visit_BracketNameNode {
  my ($self, $bracket_name_node) = @_;

  if ($self->is_comment($bracket_name_node->wri)) {
    $self->{current_number}++;
    if ($self->{current_number} == $self->comment_number) {
      $self->insert_comment($bracket_name_node);
    }
  }
}

sub is_comment {
  my ($self, $wri) = @_;

  if ($wri->isa('WiKicker::WRI::RWRN') && $wri->scheme eq 'form') {
    if ($wri->rest eq 'comment'
        || $wri->rest eq 'rcomment'
        || $wri->rest eq 'long') {
      return 1;
    }
  }
  return 0;
}
      
sub insert_comment {
  my ($self, $wri_node) = @_;

  my $type = $wri_node->wri->rest;
  my $message = '';
  if ($type ne 'long') {
    $message = '- ';
  }

  #$message .= '[[gmtime:' . $self->comment_gmtime . "]] ''";
  $message .= '[[datetime:' . WiKicker::Time::gmtime_to_W3CDTF_UTC($self->comment_gmtime) . "]] ''";
  $message .= WiKicker::PageName::armor_name($self->comment_name);
  $message .= "'': " . $self->comment_message;

  if ($type eq 'long') {
    $message .= "\n";
  }
  
  if ($type eq 'comment' ||  $type eq 'long') {
    $self->{parent}->insert_before(WiKicker::WikiPage::TextNode->new($message . "\n"), $wri_node);
  }
  else {
    $self->{parent}->insert_after(WiKicker::WikiPage::TextNode->new("\n" . $message), $wri_node);
  }
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiPage/InsertCommentVisitor.pm <==
#
# WiKicker
#
#  InsertCommitVisitor.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: InsertCommentVisitor.pm,v 1.5 2004/08/03 12:55:52 naney Exp $
#
#

package WiKicker::WikiPage::InsertCommentVisitor;

use strict;

use WiKicker::PageName;
use WiKicker::WikiPage::TraverseVisitor;
use WiKicker::WikiPage::TextNode;
use WiKicker::Time;
use vars qw(@ISA);
@ISA = qw(WiKicker::WikiPage::TraverseVisitor);

sub new {
  my $class = shift;

  my $self = bless { current_number => -1 }, $class;
}

sub comment_name {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{comment_name} = $value;
  }
  return $self->{comment_name};
}

sub comment_number {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{comment_number} = $value;
  }
  return $self->{comment_number};
}

sub comment_message {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{comment_message} = $value;
  }
  return $self->{comment_message};
}

sub comment_gmtime {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{comment_gmtime} = $value;
  }
  return $self->{comment_gmtime};
}

sub visit_WriNode {
  my ($self, $wri_node) = @_;

  #warn $wri_node->wri->scheme;

  if ($self->is_comment($wri_node->wri)) {
    $self->{current_number}++;
    if ($self->{current_number} == $self->comment_number) {
      $self->insert_comment($wri_node);
    }
  }
}

sub visit_BracketNameNode {
  my ($self, $bracket_name_node) = @_;

  if ($self->is_comment($bracket_name_node->wri)) {
    $self->{current_number}++;
    if ($self->{current_number} == $self->comment_number) {
      $self->insert_comment($bracket_name_node);
    }
  }
}

sub is_comment {
  my ($self, $wri) = @_;

  if ($wri->isa('WiKicker::WRI::RWRN') && $wri->scheme eq 'form') {
    if ($wri->rest eq 'comment'
        || $wri->rest eq 'rcomment'
        || $wri->rest eq 'long') {
      return 1;
    }
  }
  return 0;
}

sub insert_comment {
  my ($self, $wri_node) = @_;

  my $type = $wri_node->wri->rest;
  my $message = '';
  if ($type ne 'long') {
    $message = '- ';
  }

  #$message .= '[[gmtime:' . $self->comment_gmtime . "]] ''";
  $message .= '[[datetime:' . WiKicker::Time::gmtime_to_W3CDTF_UTC($self->comment_gmtime) . "]] ''";
  $message .= WiKicker::PageName::armor_name($self->comment_name);
  $message .= q('': ) . $self->comment_message;

  if ($type eq 'long') {
    $message .= "\n";
  }

  if ($type eq 'comment' ||  $type eq 'long') {
    $self->{parent}->insert_before(WiKicker::WikiPage::TextNode->new($message . "\n"), $wri_node);
  }
  else {
    $self->{parent}->insert_after(WiKicker::WikiPage::TextNode->new("\n" . $message), $wri_node);
  }
}

1;
